.. neurodiffeq documentation master file, created by
   sphinx-quickstart on Thu Oct 17 10:28:26 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to neurodiffeq's documentation!
=======================================

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   intro
   getstart
   advanced
   api
   how



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
